@@ -37,7 +37,7 @@ def GetDefaultStyleForDir(dirname):
     dirname: (unicode) The name of the directory.
 
   Returns:
-    The filename if found, otherwise return the glboal default (pep8).
+    The filename if found, otherwise return the global default (pep8).
   """
   dirname = os.path.abspath(dirname)
   while True:
@@ -110,8 +110,10 @@ def _FindPythonFiles(filenames, recursive, exclude):
       python_files.append(filename)
 
   if exclude:
-    return [f for f in python_files
-            if not any(fnmatch.fnmatch(f, p) for p in exclude)]
+    return [
+        f for f in python_files
+        if not any(fnmatch.fnmatch(f, p) for p in exclude)
+    ]
 
   return python_files
 
